==> flink-statefun-2.2.2-src.tgz: flink-statefun-2.2.2/statefun-flink/statefun-flink-core/src/main/java/org/apache/flink/statefun/flink/core/translation/CheckpointToMessage.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.flink.statefun.flink.core.translation;

import java.io.Serializable;
import java.util.function.LongFunction;
import org.apache.flink.statefun.flink.core.message.Message;
import org.apache.flink.statefun.flink.core.message.MessageFactory;
import org.apache.flink.statefun.flink.core.message.MessageFactoryType;

final class CheckpointToMessage implements Serializable, LongFunction<Message> {

  private static final long serialVersionUID = 1L;

  private final MessageFactoryType messageFactoryType;
  private transient MessageFactory factory;

  CheckpointToMessage(MessageFactoryType messageFactoryType) {
    this.messageFactoryType = messageFactoryType;
  }

  @Override
  public Message apply(long checkpointId) {
    return factory().from(checkpointId);
  }

  private MessageFactory factory() {
    if (factory == null) {
      factory = MessageFactory.forType(messageFactoryType);
    }
    return factory;
  }
}

==> flink-statefun-3.3.0-src.tgz: flink-statefun-3.3.0/statefun-flink/statefun-flink-core/src/main/java/org/apache/flink/statefun/flink/core/translation/CheckpointToMessage.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.flink.statefun.flink.core.translation;

import java.io.Serializable;
import java.util.function.LongFunction;
import org.apache.flink.statefun.flink.core.message.Message;
import org.apache.flink.statefun.flink.core.message.MessageFactory;
import org.apache.flink.statefun.flink.core.message.MessageFactoryKey;

final class CheckpointToMessage implements Serializable, LongFunction<Message> {

  private static final long serialVersionUID = 2L;

  private final MessageFactoryKey messageFactoryKey;
  private transient MessageFactory factory;

  CheckpointToMessage(MessageFactoryKey messageFactoryKey) {
    this.messageFactoryKey = messageFactoryKey;
  }

  @Override
  public Message apply(long checkpointId) {
    return factory().from(checkpointId);
  }

  private MessageFactory factory() {
    if (factory == null) {
      factory = MessageFactory.forKey(messageFactoryKey);
    }
    return factory;
  }
}
